==> gd32f1-0.2.1.crate: gd32f1-0.2.1/src/gd32f190/dma/ch2paddr.rs <==
#[doc = "Register `CH2PADDR` reader"]
pub struct R(crate::R<CH2PADDR_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CH2PADDR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<CH2PADDR_SPEC>> for R {
    fn from(reader: crate::R<CH2PADDR_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CH2PADDR` writer"]
pub struct W(crate::W<CH2PADDR_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CH2PADDR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<CH2PADDR_SPEC>> for W {
    fn from(writer: crate::W<CH2PADDR_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `PADDR` reader - Peripheral base address"]
pub struct PADDR_R(crate::FieldReader<u32, u32>);
impl PADDR_R {
    pub(crate) fn new(bits: u32) -> Self {
        PADDR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PADDR_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `PADDR` writer - Peripheral base address"]
pub struct PADDR_W<'a> {
    w: &'a mut W,
}
impl<'a> PADDR_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Peripheral base address"]
    #[inline(always)]
    pub fn paddr(&self) -> PADDR_R {
        PADDR_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Peripheral base address"]
    #[inline(always)]
    pub fn paddr(&mut self) -> PADDR_W {
        PADDR_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "DMA channel 2 peripheral base address register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ch2paddr](index.html) module"]
pub struct CH2PADDR_SPEC;
impl crate::RegisterSpec for CH2PADDR_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [ch2paddr::R](R) reader structure"]
impl crate::Readable for CH2PADDR_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [ch2paddr::W](W) writer structure"]
impl crate::Writable for CH2PADDR_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CH2PADDR to value 0"]
impl crate::Resettable for CH2PADDR_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> gd32f1-0.5.0.crate: gd32f1-0.5.0/src/gd32f190/dma/ch2paddr.rs <==
#[doc = "Register `CH2PADDR` reader"]
pub struct R(crate::R<CH2PADDR_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CH2PADDR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CH2PADDR_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CH2PADDR_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CH2PADDR` writer"]
pub struct W(crate::W<CH2PADDR_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CH2PADDR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<CH2PADDR_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<CH2PADDR_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `PADDR` reader - Peripheral base address"]
pub struct PADDR_R(crate::FieldReader<u32, u32>);
impl PADDR_R {
    pub(crate) fn new(bits: u32) -> Self {
        PADDR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PADDR_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `PADDR` writer - Peripheral base address"]
pub struct PADDR_W<'a> {
    w: &'a mut W,
}
impl<'a> PADDR_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Peripheral base address"]
    #[inline(always)]
    pub fn paddr(&self) -> PADDR_R {
        PADDR_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Peripheral base address"]
    #[inline(always)]
    pub fn paddr(&mut self) -> PADDR_W {
        PADDR_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "DMA channel 2 peripheral base address register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ch2paddr](index.html) module"]
pub struct CH2PADDR_SPEC;
impl crate::RegisterSpec for CH2PADDR_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [ch2paddr::R](R) reader structure"]
impl crate::Readable for CH2PADDR_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [ch2paddr::W](W) writer structure"]
impl crate::Writable for CH2PADDR_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CH2PADDR to value 0"]
impl crate::Resettable for CH2PADDR_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
